import { AdditionalData } from '@revolist/revogrid';
import { AutoSizeColumnConfig } from '@revolist/revogrid';
import { BasePlugin } from '@revolist/revogrid';
import { ColumnDataSchemaModel } from '@revolist/revogrid';
import { ColumnFilterConfig } from '@revolist/revogrid';
import { ColumnGrouping } from '@revolist/revogrid';
import { ColumnRegular } from '@revolist/revogrid';
import { ColumnTemplateProp } from '@revolist/revogrid';
import { ColumnType } from '@revolist/revogrid';
import { Components } from '@revolist/revogrid';
import { DataType } from '@revolist/revogrid';
import { default as default_2 } from '../vue/dist/vue.esm.js';
import { EditCell } from '@revolist/revogrid';
import { EditorCtr } from '@revolist/revogrid';
import { Editors } from '@revolist/revogrid';
import { ExtendedVue } from '../vue/dist/vue.esm.js/types/vue';
import { ExtraNodeFuncConfig } from '@revolist/revogrid';
import { FocusTemplateFunc } from '@revolist/revogrid';
import { GroupingOptions } from '@revolist/revogrid';
import { HyperFunc } from '@revolist/revogrid';
import { RowDefinition } from '@revolist/revogrid';
import { RowHeaders } from '@revolist/revogrid';
import { SortingConfig } from '@revolist/revogrid';
import { VNode } from '@revolist/revogrid';
import { VueConstructor } from '../vue/dist/vue.esm.js';

/**
 * Create editor constructor.
 * This function creates editor constructor by wrapping it with VueEditorAdapter
 * which is responsible for connecting editor with Vue lifecycle events
 */
declare const Editor: (vueConstructor: VueConstructor) => EditorCtr;
export { Editor }
export { Editor as VGridVueEditor }

/**
 * Data passed to editor
 */
export declare type EditorType = {
    column: ColumnDataSchemaModel;
    save: (value: any, preventFocus?: boolean) => void;
    close: (focusNext?: boolean) => void;
} & Partial<EditCell>;

/**
 * Vue template wrapper for virtual nodes
 */
declare const Template: (cntr: VueConstructor, customProps?: any) => (h: HyperFunc<VNode>, p: ColumnDataSchemaModel | ColumnTemplateProp, addition?: any) => VNode;
export { Template }
export { Template as VGridVueTemplate }

declare const VGrid: () => Promise<ExtendedVue<default_2, unknown, {
refresh: Components.RevoGrid["refresh"];
setDataAt: Components.RevoGrid["setDataAt"];
scrollToRow: Components.RevoGrid["scrollToRow"];
scrollToColumnIndex: Components.RevoGrid["scrollToColumnIndex"];
scrollToColumnProp: Components.RevoGrid["scrollToColumnProp"];
updateColumns: Components.RevoGrid["updateColumns"];
addTrimmed: Components.RevoGrid["addTrimmed"];
scrollToCoordinate: Components.RevoGrid["scrollToCoordinate"];
setCellEdit: Components.RevoGrid["setCellEdit"];
setCellsFocus: Components.RevoGrid["setCellsFocus"];
getSource: Components.RevoGrid["getSource"];
getVisibleSource: Components.RevoGrid["getVisibleSource"];
getSourceStore: Components.RevoGrid["getSourceStore"];
getColumnStore: Components.RevoGrid["getColumnStore"];
updateColumnSorting: Components.RevoGrid["updateColumnSorting"];
clearSorting: Components.RevoGrid["clearSorting"];
getColumns: Components.RevoGrid["getColumns"];
clearFocus: Components.RevoGrid["clearFocus"];
getPlugins: Components.RevoGrid["getPlugins"];
getFocused: Components.RevoGrid["getFocused"];
getContentSize: Components.RevoGrid["getContentSize"];
getSelectedRange: Components.RevoGrid["getSelectedRange"];
refreshExtraElements: Components.RevoGrid["refreshExtraElements"];
getProviders: Components.RevoGrid["getProviders"];
}, unknown, {
rowHeaders: boolean | RowHeaders;
frameSize: number;
rowSize: number;
colSize: number;
range: boolean;
readonly: boolean;
resize: boolean;
canFocus: boolean;
useClipboard: boolean;
columns: (ColumnRegular | ColumnGrouping<any>)[];
source: DataType[];
pinnedTopSource: DataType[];
pinnedBottomSource: DataType[];
rowDefinitions: RowDefinition[];
editors: Editors;
applyOnClose: boolean;
plugins: BasePlugin[];
columnTypes: {
[name: string]: ColumnType;
};
theme: string;
rowClass: string;
autoSizeColumn: boolean | AutoSizeColumnConfig;
filter: boolean | ColumnFilterConfig;
sorting: SortingConfig | undefined;
focusTemplate: FocusTemplateFunc;
canMoveColumns: boolean;
trimmedRows: Record<number, boolean>;
exporting: boolean;
grouping: GroupingOptions;
stretch: string | boolean;
additionalData: AdditionalData;
disableVirtualX: boolean;
disableVirtualY: boolean;
hideAttribution: boolean;
jobsBeforeRender: Promise<any>[];
registerVNode: (VNode | ((c: ExtraNodeFuncConfig) => VNode))[];
accessible: boolean;
canDrag: boolean;
}>>;
export { VGrid }
export default VGrid;

/**
 * Vue adapter to convert vue component into VNode
 */
export declare const VGridVueTemplateConstructor: (vueCtr: VueConstructor, e?: HTMLElement, p?: Record<string, any>, addition?: {
    vue: default_2;
}) => default_2 | null | undefined;


export * from "@revolist/revogrid";
export * from "@revolist/revogrid/loader";

export { }
